---
title: This is the HTML title
---

# Title

A sentence with a LaTeX math expression: $f(x) = \sin(x)$.

A simple identity in display style:

```math
\int_0^{2\pi} \sin^2(t)\,\mathrm{d}t = \pi
```
